<?php
/*
Plugin Name: Pajax
Description: Loads a page via ajax.
Version: 1.0
Author: Eric Wooley
Author URI: http://www.ericwooley.com/
*/

# get correct id for plugin
$thisfile=basename(__FILE__, ".php");

# register plugin
register_plugin(
	$thisfile, //Plugin id
	'Pajax', 	//Plugin name
	'1.0', 		//Plugin version
	'Eric Wooley',  //Plugin author
	'http://www.ericwooley.com/', //author website
	'Handles ajax requests for content.', //Plugin description
	'theme', //page type - on which admin tab to display
	'pajaxSettings'  //main function (administration)
);

# add a link in the admin tab 'theme'
add_action('theme-sidebar','createSideMenu',array($thisfile,'Pajax Settings'));

# Call pajax just before the template loads
add_action('index-pretemplate','pajax');

# Adds the jquery to the theme header
add_action('theme-header', 'pajaxLoaders');


#####################################################################
# Settings Functions
#
# Settings Key
# 0. links to load ajax from
# 1. Head to change.
# 2. Content to change.
# 3. Include jQuery?
# 4. Which animation Effect to use.
#####################################################################


# The path to the pajax settings file. It should be in GSDATAPATH
# but I found that getting permission to write to a file there was 
# inconsistant.
define('PAJAXSETTINGFILE', GSPLUGINPATH."pajax/pajax-settings.txt");

# Allows the user to edit the settings in the admin "theme" section.
function pajaxSettings(){

	# if the user saved settings
	if(isset($_POST["linkDiv"])){
		# creates a string of the new settings dilemeted by "||"
		$newSettings = 	 $_POST["linkDiv"]."||"
						.$_POST["headline"]."||"
						.$_POST["content"]."||"
						.$_POST["incJQ"]."||"
						.$_POST["effect"];

		# Write the settings to the file.
		if(file_put_contents(PAJAXSETTINGFILE, $newSettings)){
			echo "Settings Updated <br /><br />";
			//print_r($_POST);
			//print_r(pajaxReadSettings());
		}
		else
			echo "could not write file: ".PAJAXSETTINGFILE;
	}
	# reload the latest settings
	$settings = pajaxReadSettings();

	# If the "include Jquery" is set then set checked needs to be echoed
	if(strlen($settings[3]) > 1)
		$checked = "checked";
	else
		$checked = "";

	# Echo the form with updated settings
	?>
	<style>
		.pajaxInput{width: 350px;}
	</style>

	<form method='post' action=''>

		<label for="incJQ">Include a copy of jquery? (including multiple jquerys can cause issues in your javascript)</label>
		<input type='checkbox' value='Jq' name="incJQ" id="incJQ" <?php echo $checked ?>/> Include jQuery? <br />
		<br />

		<label for="linkDivs">Jquery object which contains all of your links.</label>
		<input type='text' class='pajaxInput' 
			placeholder="eg: #nav li" value='<?php echo $settings[0]; ?>' name="linkDiv" id="linkDiv" /> <br />
		<br />

		<label for="headline">Jquery object which contains the page title.</label>
		<input type='text' class='pajaxInput' 
			placeholder="eg: #header" value='<?php echo $settings[1]; ?>' name="headline" id="headline" /> <br />
		<br />

		<label for="linkDivs">Jquery object which the new content should be loaded into.</label>
		<input type='text' class='pajaxInput' 
			placeholder="eg: #content" value='<?php echo $settings[2]; ?>' name="content" id="content" /> <br />
		<br />

		<label for="effect">Effect to display before and after loading the new content.</label>
		<select class='pajaxInput' name="effect">
			<?php
				$effects = array("none", "fadeOut / fadeIn", "slideUp / slideDown");
				foreach($effects as $e){
					$sel = "";
					if($e == $settings[4] || ($e == "none" && $settings[4] == ""))
						$sel = "selected";
					?>
					<option <?php echo $sel ?>><?php echo $e ?></option>
					<?php
				}
			?>
		</select>
		<br />

		<input type='submit' value='save settings' />
	</form>

	<?php
}


# Reads the formatted settings from a file and returns an array of the settings
function pajaxReadSettings(){
	if(file_exists(PAJAXSETTINGFILE)){
		$settings = file_get_contents(PAJAXSETTINGFILE);
		return explode("||", $settings);
	}
	return $settings = array();

}

#####################################################################
# Pajax Page Manipulation Functions
#####################################################################

# Sets the theme loaders 
function pajaxLoaders(){
	#load the pajax settings
	$s = pajaxReadSettings();

	# assign settings to variables
	$nav = $s[0];
	$headline = $s[1];
	$content = $s[2];
	$jq = $s[3];
	$effect = explode(" / ", $s[4]);

	# include jquery if the user wants it.
	if(strlen($jq)>1){
		?>
		
	<script src="https://ajax.googleapis.com/ajax/libs/jquery/1.7.1/jquery.min.js"></script>

		<?php
	}

	#echo the jquery to set the onclick methods.
	?>
	
	<script type="text/javascript">
	jQuery(document).ready(function (){
		jQuery("<?php echo $nav ?>").click( function(){
			jQuery("<?php echo $headline ?>").html(jQuery(this).attr("title"));
			var title = jQuery(this).attr("title");
			var href = jQuery(this).attr("href");
			<?php
				if($effect[0] != "none" && $effect[0] != ""){
					?>
					
					jQuery("<?php echo $content ?>").<?php echo $effect[0] ?>('slow', function(){
						loadPages(href, title);

					});
					<?php
				}
				else{
					?>
					loadPages(href, title);
					<?php
				}

			?>
			
			<?php
				if($effect[0] != "none" && $effect[0] != ""){
					?>
					jQuery("<?php echo $content ?>").<?php echo $effect[1] ?>('slow');
					<?php
				}

			?>
			return false;
		});
	});
	function loadPages(href, t){
		var loading = 
			"<center>Loading "+t+"<br /><img src='<?php echo $SITEURL.'/plugins/pajax/img/ajax-loader.gif' ?>'</center>";
			jQuery("<?php echo $content ?>").html(loading);
			jQuery("<?php echo $content ?>").load(href);
	}
	</script>
	
	<?php
}

# When the page is an ajax call, only return the page contents and the kill the script.
function pajax(){
	if(isAjax()){
		echo get_page_content();
		die();	
	}
}
# checks if the request is an ajax request.
function isAjax() {
	return (isset($_SERVER['HTTP_X_REQUESTED_WITH']) && 
	($_SERVER['HTTP_X_REQUESTED_WITH'] == 'XMLHttpRequest'));
}